# -*- coding: utf-8 -*-
import os
import datetime
from django.db import models
from django.template.defaultfilters import slugify
from django.conf import settings
from django.utils.translation import ugettext_lazy as _


from jmb.core.db.fields import HTMLField, HTMLFieldTinyMCE
from jmb.core.db.models import StatusModel, DateModel, UserModel, OrderedModel



class Item(StatusModel, DateModel, UserModel, OrderedModel):
    tale = models.CharField(
        max_length=100,
        null=True,blank=True,
        default="now",
        help_text="in futuro potremmo avere più tale che mostrano contenuti dinamici",
    )
    title = models.CharField(
        _("Title"),
        max_length=200
    )
    slug = models.SlugField(
        _("Slug")
    )
    content = HTMLFieldTinyMCE(
        _("Contenuto"),
        blank=True,
        null=True,
        help_text=_("Full description"),
    )
    image = models.ImageField(
        _("Immagine"),
        blank=True, null=True,
        upload_to = "showcase/img/",
        help_text = "se è selezionato 'show_image' questa è quella che mostro"
    )
    link = models.URLField(
        _("Link"),
        blank=True,
        null=True,
        help_text= "se il 'link_type' è 'contenuto esterno' questo è il link che apro"
    )
    file = models.FileField(
        _("File"),
        blank=True,
        null=True,
        upload_to = "showcase/file/",
        help_text = "se il 'link_type' è 'contenuto scaricabile' questo è quello che scarico",
    )

    publication_date = models.DateField(
        _("Data pubblicazione"),
        default=datetime.date.today()
    )
    show_image = models.BooleanField(
        _("Show image"),
        default=True
    )
    show_link = models.BooleanField(
        _("Show link"),
        default=True
    )
    link_type = models.CharField(
        _("Link type"),
        max_length=3,
        choices=settings.SHOWCASE_LINK_TYPES,
        default='int'
    )


    class Meta:
        ordering = ["title","-publication_date"]


    def __unicode__(self):
        return self.title

#    def save(self, *args, **kwargs):
#        super(Item, self).save(*args, **kwargs)


#import cms stuffs
import jmb.showcase.cms.plugins
import jmb.showcase.cms.app
